@@ -52,6 +52,7 @@ def plot_common_taxas(common_taxas_df, **kwargs):
             "index": "Sample name",
             "value": "% of reads",
             "variable": "Taxon name",
+            "group": "Group",
         },
         template="plotly_white",
         color_discrete_sequence=colors.qualitative.Alphabet,
@@ -69,6 +70,7 @@ def plot_abund_div(abund_div_df, **kwargs):
         y="Shannon Diversity",
         size="N Taxas",
         hover_data=["index"],
+        labels={"group": "Group", "N Taxas": "# taxas"},
         template="plotly_white",
         color_discrete_sequence=colors.qualitative.Safe[3:],
         **kwargs,
@@ -84,7 +86,7 @@ def plot_beta_pcoa(beta_pcoa, **kwargs):
         x="PC1",
         y="PC2",
         hover_data=["sample"],
-        labels={"sample": "Sample name"},
+        labels={"sample": "Sample name", "group": "Group"},
         template="plotly_white",
         **kwargs,
     )
